const RED = 0.2126;
const GREEN = 0.7152;
const BLUE = 0.0722;

const GAMMA = 2.4;

class RGBA {
  r : number;
  g : number;
  b : number;
  a : number;

  constructor(r : number, g : number, b : number, a : number = 1) {
    this.r = r;
    this.g = g;
    this.b = b;
    this.a = a;
  }

  static fromHex(str : string) : RGBA {
    while (str.length && str[0] === '#') {
      str = str.slice(1);
    }

    if (str.length === 3 || str.length === 4) {
      let tmp : any = str.match(/./g);
      
      if (tmp && tmp.length) {
       tmp = (tmp as string[]).map((s : string) => parseInt(s, 16) / 15.0) as number[];
       return str.length === 4 ? new RGBA(tmp[0], tmp[1], tmp[2], tmp[3]) : new RGBA(tmp[0], tmp[1], tmp[2]);
      }
    }

    if (str.length === 6 || str.length === 8) {
      let tmp : any = str.match(/../g);
      
      if (tmp && tmp.length) {
       tmp = (tmp as string[]).map((s : string) => parseInt(s, 16) / 255.0) as number[];
       return str.length === 8 ? new RGBA(tmp[0], tmp[1], tmp[2], tmp[3]) : new RGBA(tmp[0], tmp[1], tmp[2]);
      }
    }

    throw new Error('Invalid Color!');
  }

  toHex() : string {
    return '#' + (this.a < 1 ? [this.r, this.g, this.b] : [this.r, this.g, this.b, this.a]).map(comp => Math.round(comp * 255.0).toString(16).padStart(2, '0')).join('');
  }

  luminance() {
    var a = [this.r, this.g, this.b].map((v) => {
      return v <= 0.03928
        ? v / 12.92
        : Math.pow((v + 0.055) / 1.055, GAMMA);
    });
    return a[0] * RED + a[1] * GREEN + a[2] * BLUE;
  }

  contrast(color: RGBA) : number {
    var lum1 = this.luminance();
    var lum2 = color.luminance();
    var brightest = Math.max(lum1, lum2);
    var darkest = Math.min(lum1, lum2);
    return (brightest + 0.05) / (darkest + 0.05);
  }
};

export {
  RGBA,
};

export default RGBA;
