<?php

namespace Drupal\monarch_map\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\File\FileSystemInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for Monarch Map routes.
 */
class ImageUpload extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The file system interface.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = new static();

    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->fileSystem = $container->get('file_system');

    return $instance;
  }

  /**
   * Builds the response.
   */
  public function build(Request $request) {
    $res = [];

    if ($uploadedFile = $request->files->get('file')) {
      /** @var \Symfony\Component\HttpFoundation\File\UploadedFile $uploadedFile */
      $filePath = $uploadedFile->getPathName();
      $hash = md5_file($filePath);
      $originalName = $uploadedFile->getClientOriginalName();
      $ext = pathinfo($originalName, PATHINFO_EXTENSION);
      $targetDir = 'public://svg_map_uploads/';
      $targetUri = $targetDir . $hash . '.' . $ext;

      if ($this->fileSystem->prepareDirectory($targetDir, FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS)) {
        $this->fileSystem->copy($filePath, $targetUri, FileSystemInterface::EXISTS_REPLACE);
      }

      /** @var \Drupal\file\FileStorageInterface $fs */
      $fs = $this->entityTypeManager()->getStorage('file');

      $results = $fs->loadByProperties(['uri' => $targetUri]);

      /** @var \Drupal\file\FileInterface|false $file */
      $file = reset($results);

      if (!$file) {
        /** @var \Drupal\file\FileInterface $file */
        $file = $fs->create([
          'uid' => 0,
          'uri' => $targetUri,
          'filename' => $originalName,
          'filemime' => $uploadedFile->getMimeType(),
          'langcode' => 'en',
          'status' => 1,
        ]);

        $file->save();
      }

      if ($file) {
        $res['url'] = $file->createFileUrl(TRUE);
      }
    }

    if (empty($res)) {
      return new JsonResponse([
        'error' => 'No File Found or Created',
      ], 200);
    }
    else {
      return new JsonResponse($res, 200);
    }
  }

}
