<?php

namespace Drupal\monarch_map\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the SVG map entity edit forms.
 */
class SvgMapForm extends ContentEntityForm {

  /**
   * The renderer service.
   */
  protected RendererInterface $renderer;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);

    $instance->renderer = $container->get('renderer');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = $this->getEntity();
    $result = $entity->save();
    $link = $entity->toLink($this->t('View'))->toRenderable();

    $message_arguments = ['%label' => $this->entity->label()];
    $logger_arguments = $message_arguments + ['link' => $this->renderer->render($link)];

    if ($result == SAVED_NEW) {
      $this->messenger()->addStatus($this->t('New map %label has been created.', $message_arguments));
      $this->logger('monarch_map')->notice('Created new map %label', $logger_arguments);
    }
    else {
      $this->messenger()->addStatus($this->t('The map %label has been updated.', $message_arguments));
      $this->logger('monarch_map')->notice('Updated new map %label.', $logger_arguments);
    }

    $form_state->setRedirect('entity.svg_map.canonical', ['svg_map' => $entity->id()]);
  }

}
