<?php

namespace Drupal\monarch_map\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'svg_map_data' field widget.
 *
 * @FieldWidget(
 *   id = "svg_map_data",
 *   label = @Translation("Map Data"),
 *   field_types = {"svg_map_data"},
 * )
 */
class SvgMapDataWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['app']['#markup'] = '<div data-vue-app="svg-map"></div>';
    $element['app']['#attached']['library'][] = 'monarch_map/svg_map_app';
    $element['app']['#attached']['drupalSettings']['svgMap']['defaultUnderlayColor'] = '#ddd';
    $element['app']['#attached']['drupalSettings']['svgMap']['defaultUnderlayStrokeColor'] = 'transparent';

    $element['value'] = [
      '#type' => 'hidden',
      '#default_value' => $items->value ?? NULL ?: '{}',
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    return $values;
  }

}
