<?php

namespace Drupal\monarch_map;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the svg map entity type.
 */
class SvgMapAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view svg map');

      case 'update':
        return AccessResult::allowedIfHasPermissions($account, ['edit svg map', 'administer svg map'], 'OR');

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete svg map', 'administer svg map'], 'OR');

      default:
        // No opinion.
        return AccessResult::neutral();
    }

  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['create svg map', 'administer svg map'], 'OR');
  }

}
